# Code for Paper "Maximum likelihood estimation of mixed C-vines
with application to exchange rates"

# Load necessary packages
library("CDVineMLE")

options(digits=5)

# load data
copula_daten=read.table(file="copula_daten_exchange_rates.txt")
copula_daten=cbind(copula_daten[,1:5],copula_daten[,7:9])		#without China

panel.cor <- function(x, y, digits=2, prefix="", cex.cor, ...)
{
    usr <- par("usr"); on.exit(par(usr))
    par(usr = c(0, 1, 0, 1))
    r <- cor(x,y,method="kendall")
    txt <- format(c(r, 0.123456789), digits=digits)[1]
    txt <- paste(prefix, txt, sep="")
    if(r>0.3)
	text(0.5, 0.5, txt, cex = 1.5)
    else
	text(0.5, 0.5, txt, cex = 1)
}

# First plot: pair plot with Kendall's tau
pairs(copula_daten, label=c("EUR","UK","CAN","AUS","BRA","JPN","SZ","IN"), lower.panel=panel.cor, cex=1.5,pch=".")

colnames(copula_daten)=c("EUR","UK","CAN","AUS","BRA","JPN","SZ","IN")

# Selected copula families
cop.tree1=c("t","t","t","t","t","t","N")
cop.tree2=c("t","N","G","t","t","F")
cop.tree3=c("F","F","F","t","t")
cop.tree4=c("N","G","F","N")
cop.tree5=c("N","N","N")
cop.tree6=c("N","N")
cop.tree7="N"


copulas=c(cop.tree1,cop.tree2,cop.tree3,cop.tree4,cop.tree5,cop.tree6,cop.tree7)

# Order the data
copula_daten=cbind(copula_daten[,1],copula_daten[,4],copula_daten[,7],copula_daten[,5],copula_daten[,3],copula_daten[,8],copula_daten[,6],copula_daten[,2])
colnames(copula_daten)=c("EUR","AUS","SZ","BRA","CAN","IN","JPN","UK")

# ... and the according copula families
cop.tree1=c(cop.tree1[3],cop.tree1[6],cop.tree1[4],cop.tree1[2],cop.tree1[7],cop.tree1[5],cop.tree1[1])
cop.tree2=c(cop.tree2[5],cop.tree2[3],cop.tree2[2],cop.tree2[6],cop.tree2[4],cop.tree2[1])
cop.tree3=c(cop.tree3[3],cop.tree3[2],cop.tree3[5],cop.tree3[4],cop.tree3[1])
cop.tree4=c(cop.tree4[2],cop.tree4[4],cop.tree4[3],cop.tree4[1])
cop.tree5=c(cop.tree5[3],cop.tree5[2],cop.tree5[1])
cop.tree6=c(cop.tree6[2],cop.tree6[1])

copulas=c(cop.tree1,cop.tree2,cop.tree3,cop.tree4,cop.tree5,cop.tree6,cop.tree7)

# Transform the copula families to number according to our package CDRVineMLE
copFam<-function(copula)
{
	family=0
	if(copula=="N"){family=1}
	else if(copula=="t"){family=2}
	else if(copula=="C"){family=3}
	else if(copula=="G"){family=4}
	else if(copula=="F"){family=5}
	else if(copula=="J"){family=6}
	else if(copula=="BB1"){family=7}
	else if(copula=="BB2"){family==8}
	else if(copula=="BB7"){family=9}
	else if(copula=="I"){family=0}
	
return(family)
}


fam=rep(0,dd)
for(i in 1:dd)
{
	fam[i]=copFam(copulas[i])
}


# starting values of the copula parameters
param_start=InitStageValues(copula_daten,fam,type=1)
param_start
 [1]  0.639251  0.885333  0.303797  0.456286  0.253828  0.364853  0.723883 -0.235032  1.325437  0.353722
[11]  1.190000 -0.181422  0.262413 -1.480000 -0.750000 -0.110052  0.483287  0.260000  1.104205  0.080453
[21] -0.870000 -0.046150  0.024996 -0.131150  0.080743  0.019663  0.050202 -0.028486 10.161002  4.002569
[31]  6.393636  8.437252  4.384280  8.491471 11.362580  6.860505 11.773307 50.000000 11.912071

# log-likelihood
loglik_start=VineLogLik(param_start,as.matrix(copula_daten),fam,type=1)$loglik
loglik_start
[1] 2203.4


# Maximum likelihood
MLE=VineMLE(as.matrix(copula_daten),fam,1000,type=1)
MLE

# log-likelihood with mle parameters
loglik_end=MLE$value



# Misspecification
# All copula families are Gaussian copulas
cop_N=rep(1,28)
param_start_N=InitStageValues(copula_daten,cop_N,type=1)
param_start_N
[1]  0.643402  0.890694  0.299549  0.446533  0.253828  0.371553  0.725439
[8] -0.224404  0.374655  0.353008  0.203866 -0.169282  0.265166 -0.271165
[15] -0.129514 -0.106320  0.507647  0.042445  0.162279  0.082165 -0.169007
[22] -0.042036  0.022987 -0.131876  0.083333  0.030111  0.046869 -0.028443


loglik_start_N=VineLogLik(param_start_N,as.matrix(copula_daten),cop_N,type=1)$loglik
loglik_start_N
[1] 2077


MLE_N=VineMLE(as.matrix(copula_daten),cop_N,2500,type=1)
MLE_N
$par
[1]  0.635072  0.874492  0.306660  0.462497  0.256976  0.341938  0.720455
[8] -0.254106  0.385435  0.355007  0.185846 -0.218651  0.268999 -0.236841
[15] -0.106569 -0.109328  0.499081 -0.017107  0.152136  0.085193 -0.145854
[22] -0.040424  0.047851 -0.129590  0.095210  0.022811  0.054039 -0.025556

$value
[1] 2088.8

$counts
function	gradient    
12		 12 

$convergence
[1] 0

$message
[1] "CONVERGENCE: REL_REDUCTION_OF_F <= FACTR*EPSMCH"



par_N=MLE_N$par
loglik_N=MLE_N$value



# All copula families are t-copulas
cop_t=rep(2,28)
param_start_t=InitStageValues(copula_daten,cop_t,type=1)
param_start_t
[1]  0.639251  0.885333  0.303797  0.456286  0.256325  0.364853  0.723883
[8] -0.235032  0.381919  0.352793  0.188372 -0.181422  0.262413 -0.231576
[15] -0.109360 -0.106910  0.483287  0.027877  0.156149  0.080632 -0.130250
[22] -0.051629  0.030981 -0.118425  0.074476  0.029236  0.054861 -0.019365
[29] 10.161002  4.002569  6.393636  8.437252 35.900242  4.384280  8.491471
[36] 11.362580 10.749518 11.650672 40.766147  6.860505 11.773307 50.000000
[43] 50.000000 50.000000 11.912071  8.691067 15.196315 50.000000 46.707653
[50] 50.000000 16.568377 21.573358 50.000000 14.449501 23.807215 50.000000


loglik_start_t=VineLogLik(param_start_t,as.matrix(copula_daten),cop_t,type=1)$loglik
loglik_start_t
[1] 2212.1


MLE_t=VineMLE(as.matrix(copula_daten),cop_t,2500,type=1)
MLE_t
$par
[1]    0.632546    0.887355    0.308969    0.454683    0.259331    0.371737
[7]    0.725185   -0.233936    0.376576    0.356214    0.185816   -0.183111
[13]    0.259779   -0.236818   -0.113379   -0.112084    0.491319    0.028463
[19]    0.157759    0.077975   -0.131214   -0.052844    0.033450   -0.115695
[25]    0.074085    0.030449    0.055250   -0.016887   12.892506    4.772278
[31]    7.065126    8.892698   33.117678    5.923329    9.241988   16.876522
[37]   12.557729   11.789379   43.822366    8.033376   11.510017  132.441778
[43] 5975.882583  249.699717   12.773951    8.564627   15.220903 1293.908049
[49]   39.935660   82.281905   17.820496   19.445465 4594.355371   13.802302
[55]   23.807936 2308.820845

$value
[1] 2217.5

$counts
function gradient   
451      451 

$convergence
[1] 0

$message
[1] "CONVERGENCE: REL_REDUCTION_OF_F <= FACTR*EPSMCH"



# Model with independent copulas

# Bisherige Familien
fam

cop.tree1=c("t","t","t","t","t","t","N")
cop.tree2=c("t","N","G","t","t","F")
cop.tree3=c("I","F","F","t","t")
cop.tree4=c("I","G","F","N")
cop.tree5=c("N","N","I")
cop.tree6=c("I","I")
cop.tree7="I"


copulas=c(cop.tree1,cop.tree2,cop.tree3,cop.tree4,cop.tree5,cop.tree6,cop.tree7)

cop.tree1=c(cop.tree1[3],cop.tree1[6],cop.tree1[4],cop.tree1[2],cop.tree1[7],cop.tree1[5],cop.tree1[1])
cop.tree2=c(cop.tree2[5],cop.tree2[3],cop.tree2[2],cop.tree2[6],cop.tree2[4],cop.tree2[1])
cop.tree3=c(cop.tree3[3],cop.tree3[2],cop.tree3[5],cop.tree3[4],cop.tree3[1])
cop.tree4=c(cop.tree4[2],cop.tree4[4],cop.tree4[3],cop.tree4[1])
cop.tree5=c(cop.tree5[3],cop.tree5[2],cop.tree5[1])
cop.tree6=c(cop.tree6[2],cop.tree6[1])

copulas=c(cop.tree1,cop.tree2,cop.tree3,cop.tree4,cop.tree5,cop.tree6,cop.tree7)

fam_new=rep(0,dd)

for(i in 1:dd)
{
	fam_new[i]=copFam(copulas[i])
}


# starting values
param_start_new=InitStageValues(copula_daten,fam_new,type=1)
param_start_new

# log-likelihood
loglik_start_new=VineLogLik(param_start_new,as.matrix(copula_daten),fam_new,type=1)$loglik
loglik_start_new


# Maximum likelihood
MLE_new=VineMLE(as.matrix(copula_daten),fam_new,1000,type=1)
MLE_new

# log-likelihood with mle parameters
loglik_end_new=MLE_new$value


