# simulation study for chapter 5

# load necessary functions
source("simFunctions.r")

# setting
r=100
n=2000
copula="BB1"
fam=7
d=4
dd=6
fam=rep(fam,dd)

# one plot with tau low (tau = 0.2) and symmetric tail-dependence
delta1=1.0912
theta1=0.2910
# one plot with tau high (tau = 0.8) and symmetric tail-dependence
delta2=3.5652
theta2=0.8048
# one plot with tau high (tau = 0.8) and 2*lambda_L=lambda_U
delta3=4.6018
theta3=0.1730
# one plot with tau high (tau = 0.8) and 1/2*lambda_L=lambda_U
delta4=1.5856
theta4=4.3067

param1=c(theta1,delta1)
param2=c(theta2,delta2)
param3=c(theta3,delta3)
param4=c(theta4,delta4)


testMLE<-function(r,n,d,fam,theta,delta)
{
	dd=d*(d-1)/2
	daten=matrix(0,nrow=n,ncol=d)
	paramMLE=matrix(0,nrow=r,ncol=dd+dd)

	for(i in 1:r)
	{
		daten=SimulateCopulaVine(n,d,fam,theta,delta,1)
		paramMLE[i,]=VineMLE(daten,fam,1000,type=1)$par
	}
return(paramMLE)
}


theta=c(rep(theta2,3),rep(theta1,3))
delta=c(rep(delta2,3),rep(delta1,3))
paramMLE_BB1_S2_K2_2000=testMLE(r,n,d,fam,theta,delta)
write(t(paramMLE_BB1_S2_K2_2000),file="paramMLE_BB1_S2_K2_2000.txt", ncolumns=12)



n=500
paramMLE_BB1_S2_K2_500=testMLE(r,n,d,fam,theta,delta)
write(t(paramMLE_BB1_S2_K2_500),file="paramMLE_BB1_S2_K2_500.txt", ncolumns=12)




#############################################################################
# Auswertung

# Auswertung des Versuchs mit 2000 Datenpunkten von Kombination 7

options(digits=4)
library(xtable)

tau_h=0.8	# high Kendall's tau 
tau_l=0.2	# low Kendall's tau
tau=matrix(0,nrow=4,ncol=6)
tau[1,]=c(tau_h,tau_h,tau_h,tau_h,tau_h,tau_h)
tau[2,]=c(tau_l,tau_l,tau_l,tau_l,tau_l,tau_l)
tau[3,]=c(tau_h,tau_h,tau_h,tau_l,tau_l,tau_l)
tau[4,]=c(tau_l,tau_l,tau_l,tau_h,tau_h,tau_h)



paramMLE_K7_2000_S1=read.table("paramMLE_K7_2000_S1.txt")
paramMLE_K7_2000_S2=read.table("paramMLE_K7_2000_S2.txt")
paramMLE_K7_2000_S3=read.table("paramMLE_K7_2000_S3.txt")
paramMLE_K7_2000_S4=read.table("paramMLE_K7_2000_S4.txt")
paramMLE_K7_2000=c(paramMLE_K7_2000_S1,paramMLE_K7_2000_S2,paramMLE_K7_2000_S3,paramMLE_K7_2000_S4)

copulas=c("BB7","t5","F","N","t10","BB1")

param_K7=matrix(0, ncol=10, nrow=4)
mittelwert_K7=matrix(0, ncol=10, nrow=4)
trim_mean_K7=matrix(0, ncol=10, nrow=4)
bias_K7=matrix(0, ncol=10, nrow=4)
Varianz_K7=matrix(0, ncol=10, nrow=4)
MSE_K7=matrix(0, ncol=10, nrow=4)
mittelwert_tau_K7=matrix(0, ncol=6, nrow=4)
trim_mean_tau_K7=matrix(0, ncol=6, nrow=4)
bias_tau_K7=matrix(0, ncol=6, nrow=4)
Varianz_tau_K7=matrix(0, ncol=6, nrow=4)
MSE_tau_K7=matrix(0, ncol=6, nrow=4)

paramMLE_tau_K7_2000=matrix(0, ncol=40, nrow=100)
for(i in 1:40)
{
	if(i==1 || i==11 || i==21 || i==31)
	{
		l=1
		for(j in 1:100)
		{	
			paramMLE_tau_K7_2000[j,i]=ftau(c(paramMLE_K7_2000[[i]][j],paramMLE_K7_2000[[i+6]][j]),copulas[l])
		}
	}
	else if(i==2 || i==12 || i==22 || i==32)
	{
		l=2
		for(j in 1:100)
		{	
			paramMLE_tau_K7_2000[j,i]=ftau(paramMLE_K7_2000[[i]][j],copulas[l])
		}
	}
	else if(i==3 || i==13 || i==23 || i==33)
	{
		l=3
		for(j in 1:100)
		{	
			paramMLE_tau_K7_2000[j,i]=ftau(paramMLE_K7_2000[[i]][j],copulas[l])
		}
	}
	else if(i==4 || i==14 || i==24 || i==34)
	{
		l=4
		for(j in 1:100)
		{	
			paramMLE_tau_K7_2000[j,i]=ftau(paramMLE_K7_2000[[i]][j],copulas[l])
		}
	}
	else if(i==5 || i==15 || i==25 || i==35)
	{
		l=5
		for(j in 1:100)
		{	
			paramMLE_tau_K7_2000[j,i]=ftau(paramMLE_K7_2000[[i]][j],copulas[l])
		}
	}
	else if(i==6 || i==16 || i==26 || i==36)
	{
		l=6
		for(j in 1:100)
		{	
			paramMLE_tau_K7_2000[j,i]=ftau(c(paramMLE_K7_2000[[i]][j],paramMLE_K7_2000[[i+4]][j]),copulas[l])
		}
	}
}

l=1
for(j in 1:4)
{
	for (i in 1:6)
	{
		param_K7[j,i]=parameter(copulas[i],tau[j,i],lambda[j,i])[1]
		mittelwert_K7[j,i]=mean(paramMLE_K7_2000[[l]])
		trim_mean_K7[j,i]=mean(paramMLE_K7_2000[[l]], trim=0.05)
		bias_K7[j,i]=mittelwert_K7[j,i]-param_K7[j,i]
		Varianz_K7[j,i]=1/(r-1)*sum((paramMLE_K7_2000[[l]]-mittelwert_K7[j,i])^2)
		MSE_K7[j,i]=Varianz_K7[j,i]+bias_K7[j,i]^2
		mittelwert_tau_K7[j,i]=mean(paramMLE_tau_K7_2000[,l])
		trim_mean_tau_K7[j,i]=mean(paramMLE_tau_K7_2000[,l], trim=0.05)
		bias_tau_K7[j,i]=mittelwert_tau_K7[j,i]-tau[j,i]
		Varianz_tau_K7[j,i]=1/(r-1)*sum((paramMLE_tau_K7_2000[,l]-mittelwert_tau_K7[j,i])^2)
		MSE_tau_K7[j,i]=Varianz_tau_K7[j,i]+bias_tau_K7[j,i]^2
		l=l+1
	}
	param_K7[j,7]=parameter(copulas[1],tau[j,1],lambda[j,1])[2]
	mittelwert_K7[j,7]=mean(paramMLE_K7_2000[[l]])
	trim_mean_K7[j,7]=mean(paramMLE_K7_2000[[l]], trim=0.05)
	bias_K7[j,7]=mittelwert_K7[j,7]-param_K7[j,7]
	Varianz_K7[j,7]=1/(r-1)*sum((paramMLE_K7_2000[[l]]-mittelwert_K7[j,7])^2)
	MSE_K7[j,7]=Varianz_K7[j,7]+bias_K7[j,7]^2
	l=l+1
	param_K7[j,8]=5
	mittelwert_K7[j,8]=mean(paramMLE_K7_2000[[l]])
	trim_mean_K7[j,8]=mean(paramMLE_K7_2000[[l]], trim=0.05)
	bias_K7[j,8]=mittelwert_K7[j,8]-param_K7[j,8]
	Varianz_K7[j,8]=1/(r-1)*sum((paramMLE_K7_2000[[l]]-mittelwert_K7[j,8])^2)
	MSE_K7[j,8]=Varianz_K7[j,8]+bias_K7[j,8]^2
	l=l+1
	param_K7[j,9]=10
	mittelwert_K7[j,9]=mean(paramMLE_K7_2000[[l]])
	trim_mean_K7[j,9]=mean(paramMLE_K7_2000[[l]], trim=0.05)
	bias_K7[j,9]=mittelwert_K7[j,9]-param_K7[j,9]
	Varianz_K7[j,9]=1/(r-1)*sum((paramMLE_K7_2000[[l]]-mittelwert_K7[j,9])^2)
	MSE_K7[j,9]=Varianz_K7[j,9]+bias_K7[j,9]^2
	l=l+1
	param_K7[j,10]=parameter(copulas[6],tau[j,6],lambda[j,6])[2]
	mittelwert_K7[j,10]=mean(paramMLE_K7_2000[[l]])
	trim_mean_K7[j,10]=mean(paramMLE_K7_2000[[l]], trim=0.05)
	bias_K7[j,10]=mittelwert_K7[j,10]-param_K7[j,10]
	Varianz_K7[j,10]=1/(r-1)*sum((paramMLE_K7_2000[[l]]-mittelwert_K7[j,10])^2)
	MSE_K7[j,10]=Varianz_K7[j,10]+bias_K7[j,10]^2
	l=l+1
}

param_K7=cbind(param_K7[,1],param_K7[,7],param_K7[,2],param_K7[,8],param_K7[,3:5],param_K7[,9],param_K7[,6],param_K7[,10])
mittelwert_K7=cbind(mittelwert_K7[,1],mittelwert_K7[,7],mittelwert_K7[,2],mittelwert_K7[,8],mittelwert_K7[,3:5],mittelwert_K7[,9],mittelwert_K7[,6],mittelwert_K7[,10])
trim_mean_K7=cbind(trim_mean_K7[,1],trim_mean_K7[,7],trim_mean_K7[,2],trim_mean_K7[,8],trim_mean_K7[,3:5],trim_mean_K7[,9],trim_mean_K7[,6],trim_mean_K7[,10])
bias_K7=cbind(bias_K7[,1],bias_K7[,7],bias_K7[,2],bias_K7[,8],bias_K7[,3:5],bias_K7[,9],bias_K7[,6],bias_K7[,10])
Varianz_K7=cbind(Varianz_K7[,1],Varianz_K7[,7],Varianz_K7[,2],Varianz_K7[,8],Varianz_K7[,3:5],Varianz_K7[,9],Varianz_K7[,6],Varianz_K7[,10])
MSE_K7=cbind(MSE_K7[,1],MSE_K7[,7],MSE_K7[,2],MSE_K7[,8],MSE_K7[,3:5],MSE_K7[,9],MSE_K7[,6],MSE_K7[,10])
mittelwert_tau_K7_1=cbind(mittelwert_tau_K7[,1],rep(0,4),mittelwert_tau_K7[,2],rep(0,4),mittelwert_tau_K7[,3:5],rep(0,4),mittelwert_tau_K7[,6],rep(0,4))
trim_mean_tau_K7_1=cbind(trim_mean_tau_K7[,1],rep(0,4),trim_mean_tau_K7[,2],rep(0,4),trim_mean_tau_K7[,3:5],rep(0,4),trim_mean_tau_K7[,6],rep(0,4))
bias_tau_K7_1=cbind(bias_tau_K7[,1],rep(0,4),bias_tau_K7[,2],rep(0,4),bias_tau_K7[,3:5],rep(0,4),bias_tau_K7[,6],rep(0,4))
Varianz_tau_K7_1=cbind(Varianz_tau_K7[,1],rep(0,4),Varianz_tau_K7[,2],rep(0,4),Varianz_tau_K7[,3:5],rep(0,4),Varianz_tau_K7[,6],rep(0,4))
MSE_tau_K7_1=cbind(MSE_tau_K7[,1],rep(0,4),MSE_tau_K7[,2],rep(0,4),MSE_tau_K7[,3:5],rep(0,4),MSE_tau_K7[,6],rep(0,4))


scenario=list(matrix(0, ncol=11, nrow=10),matrix(0, ncol=11, nrow=10),matrix(0, ncol=11, nrow=10),matrix(0, ncol=11, nrow=10))
for(i in 1:4)
{
	for(j in 1:10)
	{
	scenario[[i]][j,1]=param_K7[i,j]
	scenario[[i]][j,2]=mittelwert_K7[i,j]
	scenario[[i]][j,3]=trim_mean_K7[i,j]
	scenario[[i]][j,4]=bias_K7[i,j]
	scenario[[i]][j,5]=Varianz_K7[i,j]
	scenario[[i]][j,6]=MSE_K7[i,j]
	scenario[[i]][j,7]=mittelwert_tau_K7_1[i,j]
	scenario[[i]][j,8]=trim_mean_tau_K7_1[i,j]
	scenario[[i]][j,9]=bias_tau_K7_1[i,j]
	scenario[[i]][j,10]=Varianz_tau_K7_1[i,j]
	scenario[[i]][j,11]=MSE_tau_K7_1[i,j]
	}
}
tabelle9=rbind(scenario[[1]],scenario[[2]])
tabelle10=rbind(scenario[[3]],scenario[[4]])
ergeb9=xtable(tabelle9, digits=4, caption="Results of the stability and robustness tests of the copula combination BB7,t5,F,N,t10,BB1 in different scenarios (n=2000, r=100) (part 1).")
ergeb10=xtable(tabelle10, digits=4, caption="Results of the stability and robustness tests of the copula combination BB7,t5,F,N,t10,BB1 in different scenarios (n=2000, r=100) (part 2).")
print(ergeb9, type="latex", include.rownames = FALSE,include.colnames=FALSE, floating = TRUE, floating.environment="sidewaystable")
print(ergeb10, type="latex", include.rownames = FALSE,include.colnames=FALSE, floating = TRUE, floating.environment="sidewaystable")






#############################################################

\begin{sidewaystable}[ht]
\begin{center}
\begin{tabular}{rrrrrrrrrrr}
  \hline
  \hline
1.1792 & 1.1774 & 1.1780 & -0.0019 & 0.0005 & 0.0005 & 0.7982 & 0.7980 & -0.0018 & 0.0000 & 0.0000 \\ 
  8.4000 & 8.3899 & 8.3879 & -0.0101 & 0.0120 & 0.0121 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  0.9511 & 0.9511 & 0.9510 & 0.0000 & 0.0000 & 0.0000 & 0.8000 & 0.8000 & 0.0000 & 0.0000 & 0.0000 \\ 
  5.0000 & 5.0306 & 5.0225 & 0.0306 & 0.0160 & 0.0169 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  18.1000 & 18.0986 & 18.0967 & -0.0014 & 0.0198 & 0.0198 & 0.7991 & 0.7991 & -0.0009 & 0.0000 & 0.0000 \\ 
  0.9511 & 0.9500 & 0.9510 & -0.0010 & 0.0000 & 0.0000 & 0.7981 & 0.7998 & -0.0019 & 0.0001 & 0.0001 \\ 
  0.9511 & 0.9498 & 0.9509 & -0.0012 & 0.0000 & 0.0000 & 0.7978 & 0.7997 & -0.0022 & 0.0001 & 0.0001 \\ 
  10.0000 & 9.7995 & 9.8265 & -0.2005 & 0.7392 & 0.7794 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  6.4800 & 6.4521 & 6.4392 & -0.0279 & 0.3151 & 0.3159 & 0.8002 & 0.7994 & 0.0002 & 0.0001 & 0.0001 \\ 
  1.1792 & 1.1895 & 1.1873 & 0.0103 & 0.0035 & 0.0036 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  1.1792 & 1.1757 & 1.1752 & -0.0036 & 0.0007 & 0.0007 & 0.1958 & 0.1956 & -0.0042 & 0.0002 & 0.0002 \\ 
  0.2900 & 0.2904 & 0.2896 & 0.0004 & 0.0016 & 0.0016 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  0.3090 & 0.3133 & 0.3138 & 0.0043 & 0.0005 & 0.0005 & 0.2029 & 0.2032 & 0.0029 & 0.0002 & 0.0002 \\ 
  5.0000 & 5.0607 & 5.0353 & 0.0607 & 0.4849 & 0.4886 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  1.8600 & 1.8798 & 1.8785 & 0.0198 & 0.0190 & 0.0193 & 0.2018 & 0.2017 & 0.0018 & 0.0002 & 0.0002 \\ 
  0.3090 & 0.3089 & 0.3088 & -0.0002 & 0.0003 & 0.0003 & 0.1999 & 0.1999 & -0.0001 & 0.0002 & 0.0002 \\ 
  0.3090 & 0.3097 & 0.3104 & 0.0006 & 0.0004 & 0.0004 & 0.2005 & 0.2009 & 0.0005 & 0.0002 & 0.0002 \\ 
  10.0000 & 10.8392 & 10.2932 & 0.8392 & 19.4531 & 20.1573 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  0.1200 & 0.1212 & 0.1202 & 0.0012 & 0.0017 & 0.0017 & 0.2012 & 0.2013 & 0.0012 & 0.0002 & 0.0002 \\ 
  1.1792 & 1.1810 & 1.1812 & 0.0017 & 0.0007 & 0.0007 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
   \hline
\end{tabular}
\caption{Results of the stability and robustness tests of the copula combination BB7,t5,F,N,t10,BB1 in different scenarios (n=2000, r=100) (part 1).}
\end{center}
\end{sidewaystable}


\begin{sidewaystable}[ht]
\begin{center}
\begin{tabular}{rrrrrrrrrrr}
  \hline
  \hline
1.1792 & 1.1776 & 1.1774 & -0.0017 & 0.0049 & 0.0049 & 0.7981 & 0.7982 & -0.0019 & 0.0000 & 0.0000 \\ 
  8.4000 & 8.3857 & 8.3909 & -0.0143 & 0.0649 & 0.0651 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  0.9511 & 0.9508 & 0.9509 & -0.0002 & 0.0000 & 0.0000 & 0.7996 & 0.7996 & -0.0004 & 0.0000 & 0.0000 \\ 
  5.0000 & 5.0073 & 4.9823 & 0.0073 & 0.3656 & 0.3656 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  18.1000 & 18.0719 & 18.0710 & -0.0281 & 0.1346 & 0.1354 & 0.7987 & 0.7988 & -0.0013 & 0.0000 & 0.0000 \\ 
  0.3090 & 0.3084 & 0.3082 & -0.0006 & 0.0003 & 0.0003 & 0.1996 & 0.1995 & -0.0004 & 0.0001 & 0.0001 \\ 
  0.3090 & 0.3104 & 0.3106 & 0.0014 & 0.0005 & 0.0005 & 0.2010 & 0.2011 & 0.0010 & 0.0002 & 0.0002 \\ 
  10.0000 & 10.2182 & 10.0228 & 0.2182 & 6.0392 & 6.0868 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  0.1200 & 0.1235 & 0.1227 & 0.0035 & 0.0015 & 0.0015 & 0.2012 & 0.2015 & 0.0012 & 0.0002 & 0.0002 \\ 
  1.1792 & 1.1797 & 1.1797 & 0.0005 & 0.0008 & 0.0008 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  1.1792 & 1.1791 & 1.1790 & -0.0002 & 0.0001 & 0.0001 & 0.1973 & 0.1974 & -0.0027 & 0.0000 & 0.0000 \\ 
  0.2900 & 0.2905 & 0.2905 & 0.0005 & 0.0001 & 0.0001 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  0.3090 & 0.3095 & 0.3094 & 0.0005 & 0.0001 & 0.0001 & 0.2003 & 0.2003 & 0.0003 & 0.0000 & 0.0000 \\ 
  5.0000 & 4.9967 & 4.9954 & -0.0033 & 0.0039 & 0.0039 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  1.8600 & 1.8623 & 1.8621 & 0.0023 & 0.0025 & 0.0025 & 0.2001 & 0.2001 & 0.0001 & 0.0000 & 0.0000 \\ 
  0.9511 & 0.9506 & 0.9510 & -0.0005 & 0.0000 & 0.0000 & 0.7991 & 0.7999 & -0.0009 & 0.0000 & 0.0000 \\ 
  0.9511 & 0.9504 & 0.9509 & -0.0006 & 0.0000 & 0.0000 & 0.7988 & 0.7997 & -0.0012 & 0.0001 & 0.0001 \\ 
  10.0000 & 9.9862 & 9.9777 & -0.0138 & 0.2957 & 0.2959 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
  6.4800 & 6.5022 & 6.4849 & 0.0222 & 0.2255 & 0.2260 & 0.8004 & 0.8001 & 0.0004 & 0.0000 & 0.0000 \\ 
  1.1792 & 1.1824 & 1.1823 & 0.0031 & 0.0030 & 0.0030 & 0.0000 & 0.0000 & 0.0000 & 0.0000 & 0.0000 \\ 
   \hline
\end{tabular}
\caption{Results of the stability and robustness tests of the copula combination BB7,t5,F,N,t10,BB1 in different scenarios (n=2000, r=100) (part 2).}
\end{center}
\end{sidewaystable}






##############################################################

# Auswertung fr BB1 mit 2000

paramMLE_BB1_S2_K2_2000=read.table("paramMLE_BB1_S2_K2_2000.txt")

copulas=c("BB1","BB1","BB1","BB1","BB1","BB1")

# 1. Parameter
param1_BB1=c(rep(0.8048,3),rep(0.2910,3))
mittelwert1_BB1=rep(0,6)
trim_mean1_BB1=rep(0,6)
bias1_BB1=rep(0,6)
Varianz1_BB1=rep(0,6)
MSE1_BB1=rep(0,6)

# 2. Parameter
param2_BB1=c(rep(3.5652,3),rep(1.0912,3))
mittelwert2_BB1=rep(0,6)
trim_mean2_BB1=rep(0,6)
bias2_BB1=rep(0,6)
Varianz2_BB1=rep(0,6)
MSE2_BB1=rep(0,6)

# Kendall's tau
tau=c(rep(0.8,3),rep(0.2,3))
paramMLE_tau_BB1_2000=matrix(0, ncol=6,nrow=100)
mittelwert_tau_BB1=rep(0,6)
trim_mean_tau_BB1=rep(0,6)
bias_tau_BB1=rep(0,6)
Varianz_tau_BB1=rep(0,6)
MSE_tau_BB1=rep(0,6)

# upper tail dependence
MLE_lambda_BB1_2000=matrix(0, ncol=6,nrow=100)
lambda_BB1=c(rep(0.7854,3),rep(0.1126,3))
mittelwert_lambda_BB1=rep(0,6)
trim_mean_lambda_BB1=rep(0,6)
bias_lambda_BB1=rep(0,6)
Varianz_lambda_BB1=rep(0,6)
MSE_lambda_BB1=rep(0,6)

param=rep(0,2)
l=1
for(i in 1:6)
{
	for(j in 1:100)
	{
		param=c(paramMLE_BB1_S2_K2_2000[j,i],paramMLE_BB1_S2_K2_2000[j,i+6])
		paramMLE_tau_BB1_2000[j,i]=ftau(param,"BB1")
		MLE_lambda_BB1_2000[j,i]=2-2^(1/param[2])
	}
}



	for (i in 1:6)
	{
		# 1. Parameter
		#param=parameter(copulas[i],tau[i],lambda_BB1[i])
		mittelwert1_BB1[i]=mean(paramMLE_BB1_S2_K2_2000[,i])
		trim_mean1_BB1[i]=mean(paramMLE_BB1_S2_K2_2000[,i], trim=0.05)
		bias1_BB1[i]=mittelwert1_BB1[i]-param1_BB1[i]
		Varianz1_BB1[i]=1/(r-1)*sum((paramMLE_BB1_S2_K2_2000[,i]-mittelwert1_BB1[i])^2)
		MSE1_BB1[i]=Varianz1_BB1[i]+bias1_BB1[i]^2

		# 2. Parameter
		mittelwert2_BB1[i]=mean(paramMLE_BB1_S2_K2_2000[,i+6])
		trim_mean2_BB1[i]=mean(paramMLE_BB1_S2_K2_2000[,i+6], trim=0.05)
		bias2_BB1[i]=mittelwert2_BB1[i]-param2_BB1[i]
		Varianz2_BB1[i]=1/(r-1)*sum((paramMLE_BB1_S2_K2_2000[,i+6]-mittelwert2_BB1[i])^2)
		MSE2_BB1[i]=Varianz2_BB1[i]+bias2_BB1[i]^2

		# Kendall's tau
		mittelwert_tau_BB1[i]=mean(paramMLE_tau_BB1_2000[,i])
		trim_mean_tau_BB1[i]=mean(paramMLE_tau_BB1_2000[,i], trim=0.05)
		bias_tau_BB1[i]=mittelwert_tau_BB1[i]-tau[i]
		Varianz_tau_BB1[i]=1/(r-1)*sum((paramMLE_tau_BB1_2000[,i]-mittelwert_tau_BB1[i])^2)
		MSE_tau_BB1[i]=Varianz_tau_BB1[i]+bias_tau_BB1[i]^2

		# upper tail dependence
		mittelwert_lambda_BB1[i]=mean(MLE_lambda_BB1_2000[,i])
		trim_mean_lambda_BB1[i]=mean(MLE_lambda_BB1_2000[,i], trim=0.05)
		bias_lambda_BB1[i]=mittelwert_lambda_BB1[i]-lambda_BB1[i]
		Varianz_lambda_BB1[i]=1/(r-1)*sum((MLE_lambda_BB1_2000[,i]-mittelwert_lambda_BB1[i])^2)
		MSE_lambda_BB1[i]=Varianz_lambda_BB1[i]+bias_lambda_BB1[i]^2
		
	}



parameter_vektor=rep(0,12)
mean_vektor=rep(0,12)
trim_mean_vektor=rep(0,12)
bias_vektor=rep(0,12)
Varianz_vektor=rep(0,12)
MSE_vektor=rep(0,12)
k=1
for(i in 1:6)
{
parameter_vektor[k]=param1_BB1[i]
mean_vektor[k]=mittelwert1_BB1[i]
trim_mean_vektor[k]=trim_mean1_BB1[i]
bias_vektor[k]=bias1_BB1[i]
Varianz_vektor[k]=Varianz1_BB1[i]
MSE_vektor[k]=MSE1_BB1[i]
k=k+1
parameter_vektor[k]=param2_BB1[i]
mean_vektor[k]=mittelwert2_BB1[i]
trim_mean_vektor[k]=trim_mean2_BB1[i]
bias_vektor[k]=bias2_BB1[i]
Varianz_vektor[k]=Varianz2_BB1[i]
MSE_vektor[k]=MSE2_BB1[i]
k=k+1
}
parameter_matrix=cbind(parameter_vektor,mean_vektor,trim_mean_vektor,bias_vektor,Varianz_vektor,MSE_vektor)
tau_matrix=cbind(tau,mittelwert_tau_BB1,trim_mean_tau_BB1,bias_tau_BB1,Varianz_tau_BB1,MSE_tau_BB1)
lambda_matrix=cbind(lambda_BB1,mittelwert_lambda_BB1,trim_mean_lambda_BB1,bias_lambda_BB1,Varianz_lambda_BB1,MSE_lambda_BB1)

tabelle=rbind(parameter_matrix,tau_matrix,lambda_matrix)

ergeb=xtable(tabelle, digits=4, caption="Results of the simulation tests of the BB1-copula in different scenarios. (n=2000, r=100)")
print(ergeb, type="latex", include.rownames = FALSE,include.colnames=FALSE, floating = TRUE)


# Auswertung fr 500

paramMLE_BB1_S2_K2_500=read.table("paramMLE_BB1_S2_K2_500.txt")

copulas=c("BB1","BB1","BB1","BB1","BB1","BB1")

# 1. Parameter
param1_BB1=c(rep(0.8048,3),rep(0.2910,3))
mittelwert1_BB1=rep(0,6)
trim_mean1_BB1=rep(0,6)
bias1_BB1=rep(0,6)
Varianz1_BB1=rep(0,6)
MSE1_BB1=rep(0,6)

# 2. Parameter
param2_BB1=c(rep(3.5652,3),rep(1.0912,3))
mittelwert2_BB1=rep(0,6)
trim_mean2_BB1=rep(0,6)
bias2_BB1=rep(0,6)
Varianz2_BB1=rep(0,6)
MSE2_BB1=rep(0,6)

# Kendall's tau
tau=c(rep(0.8,3),rep(0.2,3))
paramMLE_tau_BB1_500=matrix(0, ncol=6,nrow=100)
mittelwert_tau_BB1=rep(0,6)
trim_mean_tau_BB1=rep(0,6)
bias_tau_BB1=rep(0,6)
Varianz_tau_BB1=rep(0,6)
MSE_tau_BB1=rep(0,6)

# upper tail dependence
MLE_lambda_BB1_500=matrix(0, ncol=6,nrow=100)
lambda_BB1=c(rep(0.7854,3),rep(0.1126,3))
mittelwert_lambda_BB1=rep(0,6)
trim_mean_lambda_BB1=rep(0,6)
bias_lambda_BB1=rep(0,6)
Varianz_lambda_BB1=rep(0,6)
MSE_lambda_BB1=rep(0,6)

param=rep(0,2)
l=1
for(i in 1:6)
{
	for(j in 1:100)
	{
		param=c(paramMLE_BB1_S2_K2_500[j,i],paramMLE_BB1_S2_K2_500[j,i+6])
		paramMLE_tau_BB1_500[j,i]=ftau(param,"BB1")
		MLE_lambda_BB1_500[j,i]=2-2^(1/param[2])
	}
}



	for (i in 1:6)
	{
		# 1. Parameter
		#param=parameter(copulas[i],tau[i],lambda_BB1[i])
		mittelwert1_BB1[i]=mean(paramMLE_BB1_S2_K2_500[,i])
		trim_mean1_BB1[i]=mean(paramMLE_BB1_S2_K2_500[,i], trim=0.05)
		bias1_BB1[i]=mittelwert1_BB1[i]-param1_BB1[i]
		Varianz1_BB1[i]=1/(r-1)*sum((paramMLE_BB1_S2_K2_500[,i]-mittelwert1_BB1[i])^2)
		MSE1_BB1[i]=Varianz1_BB1[i]+bias1_BB1[i]^2

		# 2. Parameter
		mittelwert2_BB1[i]=mean(paramMLE_BB1_S2_K2_500[,i+6])
		trim_mean2_BB1[i]=mean(paramMLE_BB1_S2_K2_500[,i+6], trim=0.05)
		bias2_BB1[i]=mittelwert2_BB1[i]-param2_BB1[i]
		Varianz2_BB1[i]=1/(r-1)*sum((paramMLE_BB1_S2_K2_500[,i+6]-mittelwert2_BB1[i])^2)
		MSE2_BB1[i]=Varianz2_BB1[i]+bias2_BB1[i]^2

		# Kendall's tau
		mittelwert_tau_BB1[i]=mean(paramMLE_tau_BB1_500[,i])
		trim_mean_tau_BB1[i]=mean(paramMLE_tau_BB1_500[,i], trim=0.05)
		bias_tau_BB1[i]=mittelwert_tau_BB1[i]-tau[i]
		Varianz_tau_BB1[i]=1/(r-1)*sum((paramMLE_tau_BB1_500[,i]-mittelwert_tau_BB1[i])^2)
		MSE_tau_BB1[i]=Varianz_tau_BB1[i]+bias_tau_BB1[i]^2

		# upper tail dependence
		mittelwert_lambda_BB1[i]=mean(MLE_lambda_BB1_500[,i])
		trim_mean_lambda_BB1[i]=mean(MLE_lambda_BB1_500[,i], trim=0.05)
		bias_lambda_BB1[i]=mittelwert_lambda_BB1[i]-lambda_BB1[i]
		Varianz_lambda_BB1[i]=1/(r-1)*sum((MLE_lambda_BB1_500[,i]-mittelwert_lambda_BB1[i])^2)
		MSE_lambda_BB1[i]=Varianz_lambda_BB1[i]+bias_lambda_BB1[i]^2
		
	}



parameter_vektor=rep(0,12)
mean_vektor=rep(0,12)
trim_mean_vektor=rep(0,12)
bias_vektor=rep(0,12)
Varianz_vektor=rep(0,12)
MSE_vektor=rep(0,12)
k=1
for(i in 1:6)
{
parameter_vektor[k]=param1_BB1[i]
mean_vektor[k]=mittelwert1_BB1[i]
trim_mean_vektor[k]=trim_mean1_BB1[i]
bias_vektor[k]=bias1_BB1[i]
Varianz_vektor[k]=Varianz1_BB1[i]
MSE_vektor[k]=MSE1_BB1[i]
k=k+1
parameter_vektor[k]=param2_BB1[i]
mean_vektor[k]=mittelwert2_BB1[i]
trim_mean_vektor[k]=trim_mean2_BB1[i]
bias_vektor[k]=bias2_BB1[i]
Varianz_vektor[k]=Varianz2_BB1[i]
MSE_vektor[k]=MSE2_BB1[i]
k=k+1
}
parameter_matrix=cbind(parameter_vektor,mean_vektor,trim_mean_vektor,bias_vektor,Varianz_vektor,MSE_vektor)
tau_matrix=cbind(tau,mittelwert_tau_BB1,trim_mean_tau_BB1,bias_tau_BB1,Varianz_tau_BB1,MSE_tau_BB1)
lambda_matrix=cbind(lambda_BB1,mittelwert_lambda_BB1,trim_mean_lambda_BB1,bias_lambda_BB1,Varianz_lambda_BB1,MSE_lambda_BB1)

tabelle=rbind(parameter_matrix,tau_matrix,lambda_matrix)

ergeb=xtable(tabelle, digits=4, caption="Results of the simulation tests of the BB1-copula in different scenarios. (n=500, r=100)")
print(ergeb, type="latex", include.rownames = FALSE,include.colnames=FALSE, floating = TRUE)



#########################################################################


\begin{table}[ht]
\begin{center}
\begin{tabular}{rrrrrr}
  \hline
  \hline
0.8048 & 0.7698 & 0.7704 & -0.0350 & 0.0059 & 0.0071 \\ 
  3.5652 & 3.6058 & 3.6060 & 0.0406 & 0.0118 & 0.0134 \\ 
  0.8048 & 0.7633 & 0.7669 & -0.0415 & 0.0075 & 0.0092 \\ 
  3.5652 & 3.6058 & 3.6045 & 0.0406 & 0.0162 & 0.0179 \\ 
  0.8048 & 0.7461 & 0.7511 & -0.0587 & 0.0101 & 0.0136 \\ 
  3.5652 & 3.6202 & 3.6156 & 0.0550 & 0.0194 & 0.0225 \\ 
  0.2910 & 0.2989 & 0.2982 & 0.0079 & 0.0018 & 0.0019 \\ 
  1.0912 & 1.0871 & 1.0867 & -0.0041 & 0.0005 & 0.0005 \\ 
  0.2910 & 0.2974 & 0.2967 & 0.0064 & 0.0019 & 0.0019 \\ 
  1.0912 & 1.0866 & 1.0868 & -0.0046 & 0.0005 & 0.0005 \\ 
  0.2910 & 0.2929 & 0.2925 & 0.0019 & 0.0022 & 0.0022 \\ 
  1.0912 & 1.0912 & 1.0909 & 0.0000 & 0.0005 & 0.0005 \\ 
  0.8000 & 0.7995 & 0.7994 & -0.0005 & 0.0000 & 0.0000 \\ 
  0.8000 & 0.7990 & 0.7991 & -0.0010 & 0.0000 & 0.0000 \\ 
  0.8000 & 0.7985 & 0.7985 & -0.0015 & 0.0000 & 0.0000 \\ 
  0.2000 & 0.1993 & 0.1990 & -0.0007 & 0.0002 & 0.0002 \\ 
  0.2000 & 0.1985 & 0.1988 & -0.0015 & 0.0001 & 0.0002 \\ 
  0.2000 & 0.2002 & 0.2003 & 0.0002 & 0.0002 & 0.0002 \\ 
  0.7854 & 0.7878 & 0.7879 & 0.0024 & 0.0000 & 0.0001 \\ 
  0.7854 & 0.7877 & 0.7878 & 0.0023 & 0.0001 & 0.0001 \\ 
  0.7854 & 0.7886 & 0.7885 & 0.0032 & 0.0001 & 0.0001 \\ 
  0.1126 & 0.1074 & 0.1072 & -0.0052 & 0.0006 & 0.0006 \\ 
  0.1126 & 0.1069 & 0.1073 & -0.0057 & 0.0006 & 0.0006 \\ 
  0.1126 & 0.1119 & 0.1117 & -0.0007 & 0.0006 & 0.0006 \\ 
   \hline
\end{tabular}
\caption{Results of the simulation tests of the BB1-copula in different scenarios. (n=2000, r=100)}
\end{center}
\end{table}


\begin{table}[ht]
\begin{center}
\begin{tabular}{rrrrrr}
  \hline
  \hline
0.8048 & 0.7936 & 0.7994 & -0.0112 & 0.0251 & 0.0253 \\ 
  3.5652 & 3.5944 & 3.5856 & 0.0292 & 0.0607 & 0.0616 \\ 
  0.8048 & 0.7906 & 0.8062 & -0.0142 & 0.0399 & 0.0401 \\ 
  3.5652 & 3.5893 & 3.5679 & 0.0241 & 0.0811 & 0.0817 \\ 
  0.8048 & 0.7569 & 0.7676 & -0.0479 & 0.0356 & 0.0379 \\ 
  3.5652 & 3.6398 & 3.6290 & 0.0746 & 0.0683 & 0.0739 \\ 
  0.2910 & 0.3022 & 0.3028 & 0.0112 & 0.0072 & 0.0074 \\ 
  1.0912 & 1.0870 & 1.0876 & -0.0042 & 0.0015 & 0.0015 \\ 
  0.2910 & 0.2885 & 0.2862 & -0.0025 & 0.0076 & 0.0076 \\ 
  1.0912 & 1.0879 & 1.0866 & -0.0033 & 0.0020 & 0.0020 \\ 
  0.2910 & 0.2793 & 0.2790 & -0.0117 & 0.0066 & 0.0067 \\ 
  1.0912 & 1.0967 & 1.0965 & 0.0055 & 0.0020 & 0.0020 \\ 
  0.8000 & 0.7999 & 0.7997 & -0.0001 & 0.0001 & 0.0001 \\ 
  0.8000 & 0.7990 & 0.7990 & -0.0010 & 0.0001 & 0.0001 \\ 
  0.8000 & 0.7995 & 0.7998 & -0.0005 & 0.0001 & 0.0001 \\ 
  0.2000 & 0.1993 & 0.1988 & -0.0007 & 0.0008 & 0.0008 \\ 
  0.2000 & 0.1950 & 0.1941 & -0.0050 & 0.0008 & 0.0008 \\ 
  0.2000 & 0.1983 & 0.1985 & -0.0017 & 0.0007 & 0.0007 \\ 
  0.7854 & 0.7862 & 0.7860 & 0.0008 & 0.0002 & 0.0002 \\ 
  0.7854 & 0.7855 & 0.7848 & 0.0001 & 0.0003 & 0.0003 \\ 
  0.7854 & 0.7890 & 0.7888 & 0.0036 & 0.0003 & 0.0003 \\ 
  0.1126 & 0.1060 & 0.1073 & -0.0066 & 0.0019 & 0.0019 \\ 
  0.1126 & 0.1063 & 0.1057 & -0.0063 & 0.0024 & 0.0024 \\ 
  0.1126 & 0.1161 & 0.1167 & 0.0035 & 0.0023 & 0.0024 \\ 
   \hline
\end{tabular}
\caption{Results of the simulation tests of the BB1-copula in different scenarios. (n=500, r=100)}
\end{center}
\end{table}
