#########################################################
# data set: Exchange rates				#
#							#
# data are transformed by ARMA(1,1)+GARCH(1,1) models	#
#########################################################


# read data
options(digits=5)
exchange.rates=read.csv(file="C:/183216668.csv",h=T)
attach(exchange.rates)
T=dim(exchange.rates)[1]
d=dim(exchange.rates)[2]

names(exchange.rates)
exchange.rates2=cbind(exeuus,exukus,excaus,exalus,exbzus,exchus,exjpus,exszus,exinus)
exchange.rates2=exchange.rates2[3919:T,]
Sys.setlocale("LC_TIME", "English") 
datum=strptime(exchange.rates$date[3919:T],format="%d%b%Y")

# fill the holes in teh data
exchange.rates2[32,1:5]=exchange.rates2[31,1:5]
exchange.rates2[32,7:9]=exchange.rates2[31,7:9]

# data inversion
#exchange.rates2=1/exchange.rates2

A1w<-exchange.rates2[,1]
A2w<-exchange.rates2[,2]
A3w<-exchange.rates2[,3]
A4w<-exchange.rates2[,4]
A5w<-exchange.rates2[,5]
A6w<-exchange.rates2[,6]
A7w<-exchange.rates2[,7]
A8w<-exchange.rates2[,8]
A9w<-exchange.rates2[,9]

# load package for time series analysis
library(fGarch)


# fit ARMA(1,1)-GARCH(1,1) to the data
fit13=garchFit(formula=~arma(1,1)+garch(1,1),data=A1w,include.mean=TRUE, include.delta=NULL, include.skew=NULL, include.shape=NULL, trace=FALSE, title=NULL, description=NULL)
res1w3<-residuals(fit13,standardize=TRUE)

fit23=garchFit(formula=~arma(1,1)+garch(1,1),data=A2w,cond.dist="std",include.mean=TRUE,include.delta=NULL,include.skew=NULL,include.shape=NULL,trace=FALSE,title=NULL,description=NULL)
res2w3<-residuals(fit23,standardize=TRUE)

fit33=garchFit(formula=~arma(1,1)+garch(1,1),data=A3w,cond.dist="std",include.mean=TRUE,include.delta=NULL,include.skew=NULL,include.shape=NULL,trace=FALSE,title=NULL,description=NULL)
res3w3<-residuals(fit33,standardize=TRUE)

fit43=garchFit(formula=~arma(1,1)+garch(1,1),data=A4w,include.mean=TRUE,include.delta=NULL,include.skew=NULL,include.shape=NULL,trace=FALSE,title=NULL,description=NULL)
res4w3<-residuals(fit43,standardize=TRUE)

fit53=garchFit(formula=~arma(1,1)+garch(1,1),data=A5w,cond.dist="std",include.mean=TRUE,include.delta=NULL,include.skew=NULL,include.shape=NULL,trace=FALSE,title=NULL,description=NULL)
res5w3<-residuals(fit53,standardize=TRUE)

fit63=garchFit(formula=~arma(1,1)+garch(1,1),data=A6w,cond.dist="std",include.mean=TRUE,include.delta=NULL,include.skew=NULL,include.shape=NULL,trace=FALSE,title=NULL,description=NULL)
res6w3<-residuals(fit63,standardize=TRUE)

fit73=garchFit(formula=~arma(1,1)+garch(1,1),data=A7w,cond.dist="sstd",include.mean=TRUE,include.delta=NULL,include.skew=NULL,include.shape=NULL,trace=FALSE,title=NULL,description=NULL)
res7w3<-residuals(fit73,standardize=TRUE)

fit83=garchFit(formula=~arma(1,1)+garch(1,1),data=A8w,include.mean=TRUE,include.delta=NULL,include.skew=NULL,include.shape=NULL,trace=FALSE,title=NULL,description=NULL)
res8w3<-residuals(fit83,standardize=TRUE)

fit93=garchFit(formula=~arma(1,1)+garch(1,1),data=A9w,cond.dist="sstd",include.mean=TRUE,include.delta=NULL,include.skew=NULL,include.shape=NULL,trace=FALSE,title=NULL,description=NULL)
res9w3<-residuals(fit93,standardize=TRUE)


# transform the residuals to copula data via empirical cdf
# to avoid the boundery cases we multiply with a factor close to 1

fak<-length(res1w3)/(length(res1w3)+1)

cdf<-ecdf(res1w3)
o1<-cdf(res1w3)
o1<-o1*fak

cdf2<-ecdf(res2w3)
o2<-cdf2(res2w3)
o2<-o2*fak

cdf3<-ecdf(res3w3)
o3<-cdf3(res3w3)
o3<-o3*fak

cdf4<-ecdf(res4w3)
o4<-cdf4(res4w3)
o4<-o4*fak

cdf5<-ecdf(res5w3)
o5<-cdf5(res5w3)
o5<-o5*fak

cdf6<-ecdf(res6w3)
o6<-cdf6(res6w3)
o6<-o6*fak

cdf7<-ecdf(res7w3)
o7<-cdf7(res7w3)
o7<-o7*fak

cdf8<-ecdf(res8w3)
o8<-cdf8(res8w3)
o8<-o8*fak

cdf9<-ecdf(res9w3)
o9<-cdf9(res9w3)
o9<-o9*fak

unifwechsel<-cbind(o1,o2,o3,o4,o5,o6,o7,o8,o9)

save(unifwechsel, file="copula_daten_exchange_rates.RData")
write(t(unifwechsel), "copula_daten_exchange_rates.txt", ncolumns=9)
